# -*- coding: utf-8 -*-
# snapshottest: v1 - https://goo.gl/zC4yUc
from __future__ import unicode_literals

from snapshottest import Snapshot

snapshots = Snapshot()

snapshots["test_query_html context"] = {
    "config": {
        "adminUrl": "/admin/data_browser/view/add/",
        "allModelFields": {
            "auth.Group": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "name"],
            },
            "auth.User": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "date_joined": {
                        "concrete": True,
                        "model": "datetime",
                        "prettyName": "date_joined",
                        "type": "datetime",
                    },
                    "email": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "email",
                        "type": "string",
                    },
                    "first_name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "first_name",
                        "type": "string",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "is_active": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "is_active",
                        "type": "boolean",
                    },
                    "is_staff": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "is_staff",
                        "type": "boolean",
                    },
                    "is_superuser": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "is_superuser",
                        "type": "boolean",
                    },
                    "last_login": {
                        "concrete": True,
                        "model": "datetime",
                        "prettyName": "last_login",
                        "type": "datetime",
                    },
                    "last_name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "last_name",
                        "type": "string",
                    },
                    "password": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "password",
                        "type": "string",
                    },
                    "username": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "username",
                        "type": "string",
                    },
                },
                "sortedFields": [
                    "id",
                    "admin",
                    "date_joined",
                    "email",
                    "first_name",
                    "is_active",
                    "is_staff",
                    "is_superuser",
                    "last_login",
                    "last_name",
                    "password",
                    "username",
                ],
            },
            "boolean": {
                "fields": {
                    "average": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "average",
                        "type": "number",
                    },
                    "sum": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "sum",
                        "type": "number",
                    },
                },
                "sortedFields": ["average", "sum"],
            },
            "data_browser.View": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "created_time": {
                        "concrete": True,
                        "model": "datetime",
                        "prettyName": "created_time",
                        "type": "datetime",
                    },
                    "description": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "description",
                        "type": "string",
                    },
                    "fields": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "fields",
                        "type": "string",
                    },
                    "google_sheets_formula": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "google_sheets_formula",
                        "type": "string",
                    },
                    "id": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "id",
                        "type": "string",
                    },
                    "model_name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "model_name",
                        "type": "string",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                    "open_view": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "open_view",
                        "type": "string",
                    },
                    "owner": {
                        "concrete": False,
                        "model": "auth.User",
                        "prettyName": "owner",
                        "type": None,
                    },
                    "public": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "public",
                        "type": "boolean",
                    },
                    "public_link": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "public_link",
                        "type": "string",
                    },
                    "query": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "query",
                        "type": "string",
                    },
                },
                "sortedFields": [
                    "id",
                    "admin",
                    "created_time",
                    "description",
                    "fields",
                    "google_sheets_formula",
                    "model_name",
                    "name",
                    "open_view",
                    "owner",
                    "public",
                    "public_link",
                    "query",
                ],
            },
            "date": {
                "fields": {
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    },
                    "day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "day",
                        "type": "number",
                    },
                    "month": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "month",
                        "type": "month",
                    },
                    "quarter": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "quarter",
                        "type": "number",
                    },
                    "week_day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "week_day",
                        "type": "weekday",
                    },
                    "year": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "year",
                        "type": "number",
                    },
                },
                "sortedFields": [
                    "count",
                    "day",
                    "month",
                    "quarter",
                    "week_day",
                    "year",
                ],
            },
            "datetime": {
                "fields": {
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    },
                    "date": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "date",
                        "type": "date",
                    },
                    "day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "day",
                        "type": "number",
                    },
                    "hour": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "hour",
                        "type": "number",
                    },
                    "minute": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "minute",
                        "type": "number",
                    },
                    "month": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "month",
                        "type": "month",
                    },
                    "quarter": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "quarter",
                        "type": "number",
                    },
                    "second": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "second",
                        "type": "number",
                    },
                    "week_day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "week_day",
                        "type": "weekday",
                    },
                    "year": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "year",
                        "type": "number",
                    },
                },
                "sortedFields": [
                    "count",
                    "date",
                    "day",
                    "hour",
                    "minute",
                    "month",
                    "quarter",
                    "second",
                    "week_day",
                    "year",
                ],
            },
            "html": {"fields": {}, "sortedFields": []},
            "month": {"fields": {}, "sortedFields": []},
            "number": {
                "fields": {
                    "average": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "average",
                        "type": "number",
                    },
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    },
                    "max": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "max",
                        "type": "number",
                    },
                    "min": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "min",
                        "type": "number",
                    },
                    "std_dev": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "std_dev",
                        "type": "number",
                    },
                    "sum": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "sum",
                        "type": "number",
                    },
                    "variance": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "variance",
                        "type": "number",
                    },
                },
                "sortedFields": [
                    "average",
                    "count",
                    "max",
                    "min",
                    "std_dev",
                    "sum",
                    "variance",
                ],
            },
            "string": {
                "fields": {
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    }
                },
                "sortedFields": ["count"],
            },
            "tests.Address": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "bob": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "bob",
                        "type": "string",
                    },
                    "city": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "city",
                        "type": "string",
                    },
                    "fred": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "fred",
                        "type": "string",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "tom": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "tom",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "bob", "city", "fred", "tom"],
            },
            "tests.InAdmin": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "name"],
            },
            "tests.InlineAdmin": {
                "fields": {
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "in_admin": {
                        "concrete": False,
                        "model": "tests.InAdmin",
                        "prettyName": "in_admin",
                        "type": None,
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "in_admin", "name"],
            },
            "tests.Normal": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "in_admin": {
                        "concrete": False,
                        "model": "tests.InAdmin",
                        "prettyName": "in_admin",
                        "type": None,
                    },
                    "inline_admin": {
                        "concrete": False,
                        "model": "tests.InlineAdmin",
                        "prettyName": "inline_admin",
                        "type": None,
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "in_admin", "inline_admin", "name"],
            },
            "tests.Producer": {
                "fields": {
                    "address": {
                        "concrete": False,
                        "model": "tests.Address",
                        "prettyName": "address",
                        "type": None,
                    },
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "address", "name"],
            },
            "tests.Product": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "created_time": {
                        "concrete": True,
                        "model": "datetime",
                        "prettyName": "created_time",
                        "type": "datetime",
                    },
                    "default_sku": {
                        "concrete": False,
                        "model": "tests.SKU",
                        "prettyName": "default_sku",
                        "type": None,
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "is_onsale": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "is_onsale",
                        "type": "string",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                    "only_in_list_view": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "only_in_list_view",
                        "type": "string",
                    },
                    "onsale": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "onsale",
                        "type": "boolean",
                    },
                    "producer": {
                        "concrete": False,
                        "model": "tests.Producer",
                        "prettyName": "producer",
                        "type": None,
                    },
                    "size": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "size",
                        "type": "number",
                    },
                    "size_unit": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "size_unit",
                        "type": "string",
                    },
                },
                "sortedFields": [
                    "id",
                    "admin",
                    "created_time",
                    "default_sku",
                    "is_onsale",
                    "name",
                    "only_in_list_view",
                    "onsale",
                    "producer",
                    "size",
                    "size_unit",
                ],
            },
            "tests.SKU": {
                "fields": {
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                    "product": {
                        "concrete": False,
                        "model": "tests.Product",
                        "prettyName": "product",
                        "type": None,
                    },
                },
                "sortedFields": ["id", "name", "product"],
            },
            "tests.Tag": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "name"],
            },
            "weekday": {"fields": {}, "sortedFields": []},
        },
        "baseUrl": "/data_browser/",
        "savedViews": [],
        "sortedModels": [
            "auth.Group",
            "auth.User",
            "data_browser.View",
            "tests.Address",
            "tests.InAdmin",
            "tests.InlineAdmin",
            "tests.Normal",
            "tests.Producer",
            "tests.Product",
            "tests.SKU",
            "tests.Tag",
        ],
        "types": {
            "boolean": {
                "defaultLookup": "equals",
                "defaultValue": True,
                "lookups": {
                    "equals": {"type": "boolean"},
                    "is_null": {"type": "boolean"},
                    "not_equals": {"type": "boolean"},
                },
                "sortedLookups": ["equals", "not_equals", "is_null"],
            },
            "date": {
                "defaultLookup": "equals",
                "defaultValue": "today",
                "lookups": {
                    "equals": {"type": "date"},
                    "gt": {"type": "date"},
                    "gte": {"type": "date"},
                    "is_null": {"type": "boolean"},
                    "lt": {"type": "date"},
                    "lte": {"type": "date"},
                    "not_equals": {"type": "date"},
                },
                "sortedLookups": [
                    "equals",
                    "not_equals",
                    "gt",
                    "gte",
                    "lt",
                    "lte",
                    "is_null",
                ],
            },
            "datetime": {
                "defaultLookup": "equals",
                "defaultValue": "now",
                "lookups": {
                    "equals": {"type": "datetime"},
                    "gt": {"type": "datetime"},
                    "gte": {"type": "datetime"},
                    "is_null": {"type": "boolean"},
                    "lt": {"type": "datetime"},
                    "lte": {"type": "datetime"},
                    "not_equals": {"type": "datetime"},
                },
                "sortedLookups": [
                    "equals",
                    "not_equals",
                    "gt",
                    "gte",
                    "lt",
                    "lte",
                    "is_null",
                ],
            },
            "html": {
                "defaultLookup": None,
                "defaultValue": None,
                "lookups": {},
                "sortedLookups": [],
            },
            "month": {
                "defaultLookup": None,
                "defaultValue": None,
                "lookups": {},
                "sortedLookups": [],
            },
            "number": {
                "defaultLookup": "equals",
                "defaultValue": 0,
                "lookups": {
                    "equals": {"type": "number"},
                    "gt": {"type": "number"},
                    "gte": {"type": "number"},
                    "is_null": {"type": "boolean"},
                    "lt": {"type": "number"},
                    "lte": {"type": "number"},
                    "not_equals": {"type": "number"},
                },
                "sortedLookups": [
                    "equals",
                    "not_equals",
                    "gt",
                    "gte",
                    "lt",
                    "lte",
                    "is_null",
                ],
            },
            "string": {
                "defaultLookup": "equals",
                "defaultValue": "",
                "lookups": {
                    "contains": {"type": "string"},
                    "ends_with": {"type": "string"},
                    "equals": {"type": "string"},
                    "is_null": {"type": "boolean"},
                    "not_contains": {"type": "string"},
                    "not_ends_with": {"type": "string"},
                    "not_equals": {"type": "string"},
                    "not_regex": {"type": "string"},
                    "not_starts_with": {"type": "string"},
                    "regex": {"type": "string"},
                    "starts_with": {"type": "string"},
                },
                "sortedLookups": [
                    "equals",
                    "contains",
                    "starts_with",
                    "ends_with",
                    "regex",
                    "not_equals",
                    "not_contains",
                    "not_starts_with",
                    "not_ends_with",
                    "not_regex",
                    "is_null",
                ],
            },
            "weekday": {
                "defaultLookup": None,
                "defaultValue": None,
                "lookups": {},
                "sortedLookups": [],
            },
        },
        "version": "redacted",
    },
    "initialState": {
        "fields": [
            {"path": ["size"], "prettyPath": ["size"], "priority": 0, "sort": "dsc"},
            {"path": ["name"], "prettyPath": ["name"], "priority": 1, "sort": "asc"},
            {
                "path": ["size_unit"],
                "prettyPath": ["size_unit"],
                "priority": None,
                "sort": None,
            },
        ],
        "filterErrors": [None, None],
        "filters": [
            {"lookup": "lt", "path": ["size"], "prettyPath": ["size"], "value": "2"},
            {"lookup": "gt", "path": ["id"], "prettyPath": ["id"], "value": "0"},
        ],
        "model": "tests.Product",
        "results": [],
        "version": "redacted",
    },
    "sentryDsn": None,
}

snapshots["test_query_html_no_perms context"] = {
    "config": {
        "adminUrl": None,
        "allModelFields": {
            "boolean": {
                "fields": {
                    "average": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "average",
                        "type": "number",
                    },
                    "sum": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "sum",
                        "type": "number",
                    },
                },
                "sortedFields": ["average", "sum"],
            },
            "date": {
                "fields": {
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    },
                    "day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "day",
                        "type": "number",
                    },
                    "month": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "month",
                        "type": "month",
                    },
                    "quarter": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "quarter",
                        "type": "number",
                    },
                    "week_day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "week_day",
                        "type": "weekday",
                    },
                    "year": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "year",
                        "type": "number",
                    },
                },
                "sortedFields": [
                    "count",
                    "day",
                    "month",
                    "quarter",
                    "week_day",
                    "year",
                ],
            },
            "datetime": {
                "fields": {
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    },
                    "date": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "date",
                        "type": "date",
                    },
                    "day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "day",
                        "type": "number",
                    },
                    "hour": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "hour",
                        "type": "number",
                    },
                    "minute": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "minute",
                        "type": "number",
                    },
                    "month": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "month",
                        "type": "month",
                    },
                    "quarter": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "quarter",
                        "type": "number",
                    },
                    "second": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "second",
                        "type": "number",
                    },
                    "week_day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "week_day",
                        "type": "weekday",
                    },
                    "year": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "year",
                        "type": "number",
                    },
                },
                "sortedFields": [
                    "count",
                    "date",
                    "day",
                    "hour",
                    "minute",
                    "month",
                    "quarter",
                    "second",
                    "week_day",
                    "year",
                ],
            },
            "html": {"fields": {}, "sortedFields": []},
            "month": {"fields": {}, "sortedFields": []},
            "number": {
                "fields": {
                    "average": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "average",
                        "type": "number",
                    },
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    },
                    "max": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "max",
                        "type": "number",
                    },
                    "min": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "min",
                        "type": "number",
                    },
                    "std_dev": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "std_dev",
                        "type": "number",
                    },
                    "sum": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "sum",
                        "type": "number",
                    },
                    "variance": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "variance",
                        "type": "number",
                    },
                },
                "sortedFields": [
                    "average",
                    "count",
                    "max",
                    "min",
                    "std_dev",
                    "sum",
                    "variance",
                ],
            },
            "string": {
                "fields": {
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    }
                },
                "sortedFields": ["count"],
            },
            "weekday": {"fields": {}, "sortedFields": []},
        },
        "baseUrl": "/data_browser/",
        "savedViews": [],
        "sortedModels": [],
        "types": {
            "boolean": {
                "defaultLookup": "equals",
                "defaultValue": True,
                "lookups": {
                    "equals": {"type": "boolean"},
                    "is_null": {"type": "boolean"},
                    "not_equals": {"type": "boolean"},
                },
                "sortedLookups": ["equals", "not_equals", "is_null"],
            },
            "date": {
                "defaultLookup": "equals",
                "defaultValue": "today",
                "lookups": {
                    "equals": {"type": "date"},
                    "gt": {"type": "date"},
                    "gte": {"type": "date"},
                    "is_null": {"type": "boolean"},
                    "lt": {"type": "date"},
                    "lte": {"type": "date"},
                    "not_equals": {"type": "date"},
                },
                "sortedLookups": [
                    "equals",
                    "not_equals",
                    "gt",
                    "gte",
                    "lt",
                    "lte",
                    "is_null",
                ],
            },
            "datetime": {
                "defaultLookup": "equals",
                "defaultValue": "now",
                "lookups": {
                    "equals": {"type": "datetime"},
                    "gt": {"type": "datetime"},
                    "gte": {"type": "datetime"},
                    "is_null": {"type": "boolean"},
                    "lt": {"type": "datetime"},
                    "lte": {"type": "datetime"},
                    "not_equals": {"type": "datetime"},
                },
                "sortedLookups": [
                    "equals",
                    "not_equals",
                    "gt",
                    "gte",
                    "lt",
                    "lte",
                    "is_null",
                ],
            },
            "html": {
                "defaultLookup": None,
                "defaultValue": None,
                "lookups": {},
                "sortedLookups": [],
            },
            "month": {
                "defaultLookup": None,
                "defaultValue": None,
                "lookups": {},
                "sortedLookups": [],
            },
            "number": {
                "defaultLookup": "equals",
                "defaultValue": 0,
                "lookups": {
                    "equals": {"type": "number"},
                    "gt": {"type": "number"},
                    "gte": {"type": "number"},
                    "is_null": {"type": "boolean"},
                    "lt": {"type": "number"},
                    "lte": {"type": "number"},
                    "not_equals": {"type": "number"},
                },
                "sortedLookups": [
                    "equals",
                    "not_equals",
                    "gt",
                    "gte",
                    "lt",
                    "lte",
                    "is_null",
                ],
            },
            "string": {
                "defaultLookup": "equals",
                "defaultValue": "",
                "lookups": {
                    "contains": {"type": "string"},
                    "ends_with": {"type": "string"},
                    "equals": {"type": "string"},
                    "is_null": {"type": "boolean"},
                    "not_contains": {"type": "string"},
                    "not_ends_with": {"type": "string"},
                    "not_equals": {"type": "string"},
                    "not_regex": {"type": "string"},
                    "not_starts_with": {"type": "string"},
                    "regex": {"type": "string"},
                    "starts_with": {"type": "string"},
                },
                "sortedLookups": [
                    "equals",
                    "contains",
                    "starts_with",
                    "ends_with",
                    "regex",
                    "not_equals",
                    "not_contains",
                    "not_starts_with",
                    "not_ends_with",
                    "not_regex",
                    "is_null",
                ],
            },
            "weekday": {
                "defaultLookup": None,
                "defaultValue": None,
                "lookups": {},
                "sortedLookups": [],
            },
        },
        "version": "redacted",
    },
    "initialState": {
        "fields": [],
        "filterErrors": [],
        "filters": [],
        "model": "",
        "results": [],
        "version": "redacted",
    },
    "sentryDsn": None,
}

snapshots["test_query_ctx context"] = {
    "config": {
        "adminUrl": "/admin/data_browser/view/add/",
        "allModelFields": {
            "auth.Group": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "name"],
            },
            "auth.User": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "date_joined": {
                        "concrete": True,
                        "model": "datetime",
                        "prettyName": "date_joined",
                        "type": "datetime",
                    },
                    "email": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "email",
                        "type": "string",
                    },
                    "first_name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "first_name",
                        "type": "string",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "is_active": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "is_active",
                        "type": "boolean",
                    },
                    "is_staff": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "is_staff",
                        "type": "boolean",
                    },
                    "is_superuser": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "is_superuser",
                        "type": "boolean",
                    },
                    "last_login": {
                        "concrete": True,
                        "model": "datetime",
                        "prettyName": "last_login",
                        "type": "datetime",
                    },
                    "last_name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "last_name",
                        "type": "string",
                    },
                    "password": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "password",
                        "type": "string",
                    },
                    "username": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "username",
                        "type": "string",
                    },
                },
                "sortedFields": [
                    "id",
                    "admin",
                    "date_joined",
                    "email",
                    "first_name",
                    "is_active",
                    "is_staff",
                    "is_superuser",
                    "last_login",
                    "last_name",
                    "password",
                    "username",
                ],
            },
            "boolean": {
                "fields": {
                    "average": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "average",
                        "type": "number",
                    },
                    "sum": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "sum",
                        "type": "number",
                    },
                },
                "sortedFields": ["average", "sum"],
            },
            "data_browser.View": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "created_time": {
                        "concrete": True,
                        "model": "datetime",
                        "prettyName": "created_time",
                        "type": "datetime",
                    },
                    "description": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "description",
                        "type": "string",
                    },
                    "fields": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "fields",
                        "type": "string",
                    },
                    "google_sheets_formula": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "google_sheets_formula",
                        "type": "string",
                    },
                    "id": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "id",
                        "type": "string",
                    },
                    "model_name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "model_name",
                        "type": "string",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                    "open_view": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "open_view",
                        "type": "string",
                    },
                    "owner": {
                        "concrete": False,
                        "model": "auth.User",
                        "prettyName": "owner",
                        "type": None,
                    },
                    "public": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "public",
                        "type": "boolean",
                    },
                    "public_link": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "public_link",
                        "type": "string",
                    },
                    "query": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "query",
                        "type": "string",
                    },
                },
                "sortedFields": [
                    "id",
                    "admin",
                    "created_time",
                    "description",
                    "fields",
                    "google_sheets_formula",
                    "model_name",
                    "name",
                    "open_view",
                    "owner",
                    "public",
                    "public_link",
                    "query",
                ],
            },
            "date": {
                "fields": {
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    },
                    "day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "day",
                        "type": "number",
                    },
                    "month": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "month",
                        "type": "month",
                    },
                    "quarter": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "quarter",
                        "type": "number",
                    },
                    "week_day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "week_day",
                        "type": "weekday",
                    },
                    "year": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "year",
                        "type": "number",
                    },
                },
                "sortedFields": [
                    "count",
                    "day",
                    "month",
                    "quarter",
                    "week_day",
                    "year",
                ],
            },
            "datetime": {
                "fields": {
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    },
                    "date": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "date",
                        "type": "date",
                    },
                    "day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "day",
                        "type": "number",
                    },
                    "hour": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "hour",
                        "type": "number",
                    },
                    "minute": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "minute",
                        "type": "number",
                    },
                    "month": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "month",
                        "type": "month",
                    },
                    "quarter": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "quarter",
                        "type": "number",
                    },
                    "second": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "second",
                        "type": "number",
                    },
                    "week_day": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "week_day",
                        "type": "weekday",
                    },
                    "year": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "year",
                        "type": "number",
                    },
                },
                "sortedFields": [
                    "count",
                    "date",
                    "day",
                    "hour",
                    "minute",
                    "month",
                    "quarter",
                    "second",
                    "week_day",
                    "year",
                ],
            },
            "html": {"fields": {}, "sortedFields": []},
            "month": {"fields": {}, "sortedFields": []},
            "number": {
                "fields": {
                    "average": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "average",
                        "type": "number",
                    },
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    },
                    "max": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "max",
                        "type": "number",
                    },
                    "min": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "min",
                        "type": "number",
                    },
                    "std_dev": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "std_dev",
                        "type": "number",
                    },
                    "sum": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "sum",
                        "type": "number",
                    },
                    "variance": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "variance",
                        "type": "number",
                    },
                },
                "sortedFields": [
                    "average",
                    "count",
                    "max",
                    "min",
                    "std_dev",
                    "sum",
                    "variance",
                ],
            },
            "string": {
                "fields": {
                    "count": {
                        "concrete": True,
                        "model": None,
                        "prettyName": "count",
                        "type": "number",
                    }
                },
                "sortedFields": ["count"],
            },
            "tests.Address": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "bob": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "bob",
                        "type": "string",
                    },
                    "city": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "city",
                        "type": "string",
                    },
                    "fred": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "fred",
                        "type": "string",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "tom": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "tom",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "bob", "city", "fred", "tom"],
            },
            "tests.InAdmin": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "name"],
            },
            "tests.InlineAdmin": {
                "fields": {
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "in_admin": {
                        "concrete": False,
                        "model": "tests.InAdmin",
                        "prettyName": "in_admin",
                        "type": None,
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "in_admin", "name"],
            },
            "tests.Normal": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "in_admin": {
                        "concrete": False,
                        "model": "tests.InAdmin",
                        "prettyName": "in_admin",
                        "type": None,
                    },
                    "inline_admin": {
                        "concrete": False,
                        "model": "tests.InlineAdmin",
                        "prettyName": "inline_admin",
                        "type": None,
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "in_admin", "inline_admin", "name"],
            },
            "tests.Producer": {
                "fields": {
                    "address": {
                        "concrete": False,
                        "model": "tests.Address",
                        "prettyName": "address",
                        "type": None,
                    },
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "address", "name"],
            },
            "tests.Product": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "created_time": {
                        "concrete": True,
                        "model": "datetime",
                        "prettyName": "created_time",
                        "type": "datetime",
                    },
                    "default_sku": {
                        "concrete": False,
                        "model": "tests.SKU",
                        "prettyName": "default_sku",
                        "type": None,
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "is_onsale": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "is_onsale",
                        "type": "string",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                    "only_in_list_view": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "only_in_list_view",
                        "type": "string",
                    },
                    "onsale": {
                        "concrete": True,
                        "model": "boolean",
                        "prettyName": "onsale",
                        "type": "boolean",
                    },
                    "producer": {
                        "concrete": False,
                        "model": "tests.Producer",
                        "prettyName": "producer",
                        "type": None,
                    },
                    "size": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "size",
                        "type": "number",
                    },
                    "size_unit": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "size_unit",
                        "type": "string",
                    },
                },
                "sortedFields": [
                    "id",
                    "admin",
                    "created_time",
                    "default_sku",
                    "is_onsale",
                    "name",
                    "only_in_list_view",
                    "onsale",
                    "producer",
                    "size",
                    "size_unit",
                ],
            },
            "tests.SKU": {
                "fields": {
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                    "product": {
                        "concrete": False,
                        "model": "tests.Product",
                        "prettyName": "product",
                        "type": None,
                    },
                },
                "sortedFields": ["id", "name", "product"],
            },
            "tests.Tag": {
                "fields": {
                    "admin": {
                        "concrete": False,
                        "model": None,
                        "prettyName": "admin",
                        "type": "html",
                    },
                    "id": {
                        "concrete": True,
                        "model": "number",
                        "prettyName": "id",
                        "type": "number",
                    },
                    "name": {
                        "concrete": True,
                        "model": "string",
                        "prettyName": "name",
                        "type": "string",
                    },
                },
                "sortedFields": ["id", "admin", "name"],
            },
            "weekday": {"fields": {}, "sortedFields": []},
        },
        "baseUrl": "/data_browser/",
        "savedViews": [],
        "sortedModels": [
            "auth.Group",
            "auth.User",
            "data_browser.View",
            "tests.Address",
            "tests.InAdmin",
            "tests.InlineAdmin",
            "tests.Normal",
            "tests.Producer",
            "tests.Product",
            "tests.SKU",
            "tests.Tag",
        ],
        "types": {
            "boolean": {
                "defaultLookup": "equals",
                "defaultValue": True,
                "lookups": {
                    "equals": {"type": "boolean"},
                    "is_null": {"type": "boolean"},
                    "not_equals": {"type": "boolean"},
                },
                "sortedLookups": ["equals", "not_equals", "is_null"],
            },
            "date": {
                "defaultLookup": "equals",
                "defaultValue": "today",
                "lookups": {
                    "equals": {"type": "date"},
                    "gt": {"type": "date"},
                    "gte": {"type": "date"},
                    "is_null": {"type": "boolean"},
                    "lt": {"type": "date"},
                    "lte": {"type": "date"},
                    "not_equals": {"type": "date"},
                },
                "sortedLookups": [
                    "equals",
                    "not_equals",
                    "gt",
                    "gte",
                    "lt",
                    "lte",
                    "is_null",
                ],
            },
            "datetime": {
                "defaultLookup": "equals",
                "defaultValue": "now",
                "lookups": {
                    "equals": {"type": "datetime"},
                    "gt": {"type": "datetime"},
                    "gte": {"type": "datetime"},
                    "is_null": {"type": "boolean"},
                    "lt": {"type": "datetime"},
                    "lte": {"type": "datetime"},
                    "not_equals": {"type": "datetime"},
                },
                "sortedLookups": [
                    "equals",
                    "not_equals",
                    "gt",
                    "gte",
                    "lt",
                    "lte",
                    "is_null",
                ],
            },
            "html": {
                "defaultLookup": None,
                "defaultValue": None,
                "lookups": {},
                "sortedLookups": [],
            },
            "month": {
                "defaultLookup": None,
                "defaultValue": None,
                "lookups": {},
                "sortedLookups": [],
            },
            "number": {
                "defaultLookup": "equals",
                "defaultValue": 0,
                "lookups": {
                    "equals": {"type": "number"},
                    "gt": {"type": "number"},
                    "gte": {"type": "number"},
                    "is_null": {"type": "boolean"},
                    "lt": {"type": "number"},
                    "lte": {"type": "number"},
                    "not_equals": {"type": "number"},
                },
                "sortedLookups": [
                    "equals",
                    "not_equals",
                    "gt",
                    "gte",
                    "lt",
                    "lte",
                    "is_null",
                ],
            },
            "string": {
                "defaultLookup": "equals",
                "defaultValue": "",
                "lookups": {
                    "contains": {"type": "string"},
                    "ends_with": {"type": "string"},
                    "equals": {"type": "string"},
                    "is_null": {"type": "boolean"},
                    "not_contains": {"type": "string"},
                    "not_ends_with": {"type": "string"},
                    "not_equals": {"type": "string"},
                    "not_regex": {"type": "string"},
                    "not_starts_with": {"type": "string"},
                    "regex": {"type": "string"},
                    "starts_with": {"type": "string"},
                },
                "sortedLookups": [
                    "equals",
                    "contains",
                    "starts_with",
                    "ends_with",
                    "regex",
                    "not_equals",
                    "not_contains",
                    "not_starts_with",
                    "not_ends_with",
                    "not_regex",
                    "is_null",
                ],
            },
            "weekday": {
                "defaultLookup": None,
                "defaultValue": None,
                "lookups": {},
                "sortedLookups": [],
            },
        },
        "version": "redacted",
    },
    "initialState": {
        "fields": [],
        "filterErrors": [],
        "filters": [],
        "model": "",
        "results": [],
        "version": "redacted",
    },
    "sentryDsn": None,
}

snapshots["test_query_json data"] = {
    "fields": [
        {"path": ["size"], "prettyPath": ["size"], "priority": 0, "sort": "dsc"},
        {"path": ["name"], "prettyPath": ["name"], "priority": 1, "sort": "asc"},
        {
            "path": ["size_unit"],
            "prettyPath": ["size_unit"],
            "priority": None,
            "sort": None,
        },
    ],
    "filterErrors": [None, None],
    "filters": [
        {"lookup": "lt", "path": ["size"], "prettyPath": ["size"], "value": "2"},
        {"lookup": "gt", "path": ["id"], "prettyPath": ["id"], "value": "0"},
    ],
    "model": "tests.Product",
    "results": [[1.0, "a", "g"], [1.0, "b", "g"]],
    "version": "redacted",
}
